"""
_____        _____                         _ 
|  __ \      / ____|                       | |
| |__) |   _| (___   ___ _ ____   _____  __| |
|  ___/ | | |\___ \ / _ \ '__\ \ / / _ \/ _` |
| |   | |_| |____) |  __/ |   \ V /  __/ (_| |
|_|    \__, |_____/ \___|_|    \_/ \___|\__,_|
        __/ |                                 
        |___/                                  

Shaurya Pratap Singh 2021
"""

__version__ = "2.0.8"
__author__ = "SblipDev"
__github__ = "https://github.com/SblipDev/PyServed"
__logo__ = """
_____        _____                         _ 
|  __ \      / ____|                       | |
| |__) |   _| (___   ___ _ ____   _____  __| |
|  ___/ | | |\___ \ / _ \ '__\ \ / / _ \/ _` |
| |   | |_| |____) |  __/ |   \ V /  __/ (_| |
|_|    \__, |_____/ \___|_|    \_/ \___|\__,_|
        __/ |                                 
        |___/  
"""


def main():
    print(__logo__)
    print("PyServed v{}".format(__version__))
    print("Author: {0}".format(__author__))
    print("Github: {0}".format(__github__))
    print("")


main()
